const { version } = require('../package.json')

const minorVersion = `${version.split('.')[0]}.${version.split('.')[1]}.0`
const
  /**
   * The default URI base for Motion Bank resources
   * @type {string}
   */
  BASE_URI = 'http://id.motionbank.org/',
  BASE_URI_NS = `http://schema.motionbank.org/ns/${minorVersion}/`,
  BASE_URI_TERMS = `http://schema.motionbank.org/ns/${minorVersion}/terms/`

const ANNOTATION_MOTIVATIONS = [
  /**
   * Provide an assessment about the Target resource.
   * @see https://www.w3.org/TR/annotation-vocab/#assessing
   */
  'assessing',

  /**
   * Create a bookmark to the Target or part thereof.
   * @see https://www.w3.org/TR/annotation-vocab/#bookmarking
   */
  'bookmarking',

  /**
   * Classify the Target as something.
   * @see https://www.w3.org/TR/annotation-vocab/#classifying
   */
  'classifying',

  /**
   * Comment about the Target.
   * @see https://www.w3.org/TR/annotation-vocab/#commenting
   */
  'commenting',

  /**
   * Describe the Target, as opposed to a comment.
   * @see https://www.w3.org/TR/annotation-vocab/#describing
   */
  'describing',

  /**
   * Request a change or edit to the Target resource.
   * @see https://www.w3.org/TR/annotation-vocab/#editing
   */
  'editing',

  /**
   * Highlight the Target resource or segment of it.
   * @see https://www.w3.org/TR/annotation-vocab/#highlighting
   */
  'highlighting',

  /**
   * Assign an identity to the Target or identify what is being
   * depicted or described in the Target.
   * @see https://www.w3.org/TR/annotation-vocab/#identifying
   */
  'identifying',

  /**
   * Link to a resource related to the Target.
   * @see https://www.w3.org/TR/annotation-vocab/#linking
   */
  'linking',

  /**
   * Assign some value or quality to the Target.
   * @see https://www.w3.org/TR/annotation-vocab/#moderating
   */
  'moderating',

  /**
   * Ask a question about the Target.
   * @see https://www.w3.org/TR/annotation-vocab/#questioning
   */
  'questioning',

  /**
   * Reply to a previous statement, either an Annotation
   * or another resource.
   * @see https://www.w3.org/TR/annotation-vocab/#replying
   */
  'replying',

  /**
   * Associate a tag with the Target.
   * @see https://www.w3.org/TR/annotation-vocab/#tagging
   */
  'tagging'
]

/** List of possible Map types */
const
  /** Abstract Map (spatial/temporal) */
  MAP_CLASS_MAP = 'Map',
  /** MoSys Grid (spatial) */
  MAP_CLASS_GRID = 'Grid',
  /** Piecemaker Timeline (temporal) */
  MAP_CLASS_TIMELINE = 'Timeline'

const MAP_CLASSES = [
  MAP_CLASS_MAP,
  MAP_CLASS_GRID,
  MAP_CLASS_TIMELINE
]

const
  /** Abstract Map (spatial/temporal) */
  MAP_TYPE_MAP = `${BASE_URI_TERMS}${MAP_CLASS_MAP}`,
  /** MoSys Grid (spatial) */
  MAP_TYPE_GRID = `${BASE_URI_TERMS}${MAP_CLASS_GRID}`,
  /** Piecemaker Timeline (temporal) */
  MAP_TYPE_TIMELINE = `${BASE_URI_TERMS}${MAP_CLASS_TIMELINE}`

const MAP_TYPES = [
  MAP_TYPE_GRID,
  MAP_TYPE_TIMELINE,
  MAP_TYPE_MAP
]

/** Config values */
const
  TIMECODE_FORMAT = 'HH:mm:ss:SSS',
  // FIXME: is a second timecode format really needed?
  TIMECODE_FORMAT_DURATION = 'hh:mm:ss:SSS',
  SESSION_DISTANCE_SECONDS = 6 * 60 * 60

module.exports = {
  BASE_URI,
  BASE_URI_NS,
  BASE_URI_TERMS,
  ANNOTATION_MOTIVATIONS,
  MAP_TYPES,
  MAP_CLASSES,
  mapTypes: {
    MAP_TYPE_GRID,
    MAP_TYPE_TIMELINE,
    MAP_TYPE_MAP
  },
  mapClasses: {
    MAP_CLASS_GRID,
    MAP_CLASS_TIMELINE,
    MAP_CLASS_MAP
  },
  config: {
    TIMECODE_FORMAT,
    TIMECODE_FORMAT_DURATION,
    SESSION_DISTANCE_SECONDS
  }
}
