const { DateTime, Duration, Interval } = require('luxon')

const isType = function (value, type) {
  switch (type) {
    /** Test for Floats */
    case 'float':
      if (typeof value === 'number') return true
      const isFloat = /^[+-]?((\d+\.?\d*)|(\.\d+))$/
      return isFloat.test(value)

    /** Test for Integers */
    case 'integer':
      if (typeof value === 'number') return true
      const isInteger = /^([+-]?[1-9]\d*|0)$/
      return isInteger.test(value)

    /** Test for and parse ISO 8601 Date
     * @see: https://www.w3.org/TR/NOTE-datetime
     */
    case 'date':
      if (value instanceof DateTime) return true
      if (value instanceof Date) return true
      const isISODate = /^\d{4}-\d\d-\d\dT\d\d:\d\d:\d\d(\.\d+)?(([+-]\d\d:\d\d)|Z)?$/i
      return isISODate.test(value)

    /** Test for and parse ISO 8601 Duration
     * @see: https://en.wikipedia.org/wiki/ISO_8601#Durations
     */
    case 'duration':
      if (value instanceof Duration) return true
      const isISODuration = /^P(?!$)((\d+Y)|(\d+\.\d+Y$))?((\d+M)|(\d+\.\d+M$))?((\d+W)|(\d+\.\d+W$))?((\d+D)|(\d+\.\d+D$))?(T(?=\d)((\d+H)|(\d+\.\d+H$))?((\d+M)|(\d+\.\d+M$))?(\d+(\.\d+)?S)?)??$/
      return isISODuration.test(value)

    /** Test for and parse ISO 8601 Duration
     * @see: https://en.wikipedia.org/wiki/ISO_8601#Time_intervals
     */
    case 'interval':
      if (value instanceof Interval) return true
      // TODO: Test and parse ISO 8601 Interval
      return false
    default:
      return false
  }
}

module.exports = isType
