const SchemaObject = require('schema-object')
const constants = require('../../constants')
const { constructors, methods, setSpecialFields } = require('../../defaults')
const { Person, Stylesheet } = require('../internal')
const { Target, Body } = require('./sub-models')

const schema = setSpecialFields('annotations', {
  /** Document **/
  '@context': {
    type: String,
    readOnly: true,
    default: 'http://www.w3.org/ns/anno.jsonld'
  },
  type: {
    type: String,
    enum: ['Annotation'],
    default: 'Annotation'
  },

  /** Annotation data */
  creator: {
    type: Person
  },
  body: {
    type: Body
  },
  motivation: {
    type: String,
    enum: constants.ANNOTATION_MOTIVATIONS
  },
  target: {
    type: Target
  },
  stylesheet: { type: Stylesheet }
})

const config = {
  strict: false,
  constructors,
  methods
}

const Annotation = new SchemaObject(schema, config)
Annotation.schema = schema

module.exports = Annotation
